@@ -114,19 +114,19 @@ class Auth(object):
         invalid.  This number can be a float to indicate a fraction of an
         hour (e.g.: 0.5 = 30 minutes).
     
-    sign_in_view
+    sign_in_template
     :   template used to render the sign in form.
     
-    sign_out_view
+    sign_out_template
     :   template rendered after the user sign out.
         
-    change_password_view
+    change_password_template
     :   template udes to render the "Forgot your password?" form.
     
-    reset_password_view
+    reset_password_template
     :   template to render when resetting a password.
     
-    email_reset_view
+    email_reset_template
     :   template to use to send the reset-password email.
 
     render
@@ -156,11 +156,11 @@ class Auth(object):
         'password_minlen': 5,
         'reset_expire': 3,  # hours
 
-        'sign_in_view': 'auth_sign_in.html',
-        'sign_out_view': None,
-        'reset_password_view': 'auth_reset_password.html',
-        'email_reset_view': 'auth_email_reset_password.html',
-        'change_password_view': 'auth_change_password.html',
+        'sign_in_template': 'auth_sign_in.html',
+        'sign_out_template': None,
+        'reset_password_template': 'auth_reset_password.html',
+        'email_reset_template': 'auth_email_reset_password.html',
+        'change_password_template': 'auth_change_password.html',
 
         'render': None,
         'mailer': None,
@@ -389,7 +389,7 @@ class Auth(object):
         """
         time36 = time36 or to36(int(time.time()))
         key = ''.join([
-            self.app.settings.secret_key,
+            self.app.settings.SECRET_KEY,
             getattr(user, 'password', '')[10:50],
             unicode(getattr(user, 'last_sign_in', '')),
             unicode(getattr(user, 'id', 0)),
@@ -445,21 +445,21 @@ class Auth(object):
         return user
     
 
-    def render(self, view, **context):
+    def render(self, template, context):
         try:
-            return self.settings.render(view, context)
+            return self.settings.render(template, context)
         except TemplateNotFound:
-            return auth_render(view, context)
+            return auth_render(template, context)
     
 
-    def render_to_string(self, view, **context):
+    def render_to_string(self, template, context):
         try:
-            return self.settings.render.to_string(view, context)
+            return self.settings.render(template, context, to_string=True)
         except TemplateNotFound:
-            return auth_render.to_string(view, context)
+            return auth_render(template, context, to_string=True)
     
 
-    def sign_in_controller(self, request, **kwargs):
+    def sign_in_view(self, request, **kwargs):
         """Signs a user in.
         """
         redirect_to = request.session.get(REDIRECT_FIELD_NAME)
@@ -487,17 +487,13 @@ class Auth(object):
                 return redirect(redirect_to)
             kwargs['error'] = 'FAIL'
         
-        view = self.settings.sign_in_view
-        return self.render(view, **kwargs)
+        template = self.settings.sign_in_template
+        return self.render(template, kwargs)
     
 
-    def sign_out_controller(self, request, **kwargs):
+    def sign_out_view(self, request, **kwargs):
         """Signs out a user.
         
-        view
-        :   Optional full name of a view to display after
-            signing out the user.
-
         """
         redirect_to = request.session.get(REDIRECT_FIELD_NAME)
         redirect_to = redirect_to or self.settings.sign_out_redirect
@@ -506,14 +502,14 @@ class Auth(object):
         
         self.sign_out(request)
         
-        view = self.settings.sign_out_view
-        if view:
+        template = self.settings.sign_out_template
+        if template:
             kwargs['auth'] = self
-            return self.render(view, **kwargs)
+            return self.render(template, kwargs)
         return redirect(redirect_to)
     
 
-    def change_password_controller(self, request, token=None, **kwargs):
+    def change_password_view(self, request, token=None, **kwargs):
         """A apge to generate a link to reset your password.
         
         token
@@ -536,7 +532,7 @@ class Auth(object):
                 if request.user and (request.user != user):
                     self.sign_out(request)
                 self.sign_in(request, user)
-                return self.reset_password_controller(request, user_requested=False)
+                return self.reset_password_view(request, user_requested=False)
             
             kwargs['error'] = 'WRONG TOKEN'
         
@@ -552,13 +548,13 @@ class Auth(object):
                 self.email_token(user, token)
                 kwargs['ok'] = True
         
-        view = self.settings.reset_password_view
-        return self.render(view, **kwargs)
+        template = self.settings.reset_password_template
+        return self.render(template, kwargs)
     
 
     def email_token(self, user, token):
-        view = self.settings.email_reset_view
-        self.render_to_string(view, {'user': user, 'token': token})
+        template = self.settings.email_reset_template
+        self.render_to_string(template, {'user': user, 'token': token})
         msg = msg.encode('utf-8')
         
         mailer = self.settings.mailer
@@ -568,7 +564,7 @@ class Auth(object):
             from_email=mailer.default_from,
             to=user.email
         )
-        if view.endswith('.html'):
+        if template.endswith('.html'):
             email_msg.html_content = msg
         else:
             email_msg.text_content = msg
@@ -576,7 +572,7 @@ class Auth(object):
         mailer.send(email_msg)
     
 
-    def reset_password_controller(self, request, user_requested=True, **kwargs):
+    def reset_password_view(self, request, user_requested=True, **kwargs):
         """A view to change your password.
         """
         if not is_valid(request):
@@ -618,6 +614,12 @@ class Auth(object):
                 self.sign_in(request, user)
                 kwargs['ok'] = True
         
-        view = self.settings.change_password_view
-        return self.render(view, **kwargs)
+        template = self.settings.change_password_template
+        return self.render(template, kwargs)
+
+
+    sign_in_controller = sign_in_view
+    sign_out_controller = sign_out_view
+    change_password_controller = change_password_view
+    reset_password_controller = reset_password_view
 
